@@ -183,15 +183,10 @@ class ChangeLog:
             clone_list = clone_sht.values.tolist()
             clone_index = clone_sht.index.values.tolist()
             data_dic = {}
-            data_add = []
-            data_remove = {}
-            remove_keys = []
-
             for data, i in zip(source_changes.values.tolist(), source_changes.index.values.tolist()):
                 if i < len(source_sht):
                     if i not in data_dic:
                         data_dic[i] = [data, ""]
-                        data_add.append(i)
                 else:
                     if data in clone_list:
                         index = clone_index[clone_list.index(data)]
@@ -199,39 +194,30 @@ class ChangeLog:
                             data_dic[index][1] = data
                         else:
                             data_dic[index] = ["", data]
-                        data_remove[index] = index
-                        remove_keys.append(index)
-
-            for num in data_add:
-                if not remove_keys:
-                    break
-                if num < data_remove[remove_keys[0]]:
-                    for dt in remove_keys:
-                        data_remove[dt] += 1
-                while num > data_remove[remove_keys[0]]:
-                    for dt in remove_keys:
-                        data_remove[dt] -= 1
-                    remove_keys.remove(remove_keys[0])
-                    if not remove_keys:
-                        break
-
-            for ind in data_remove:
-                if data_remove[ind] != ind:
-                    if data_remove[ind] not in data_dic:
-                        data_dic[data_remove[ind]] = data_dic[ind]
-                    else:
-                        data_dic[data_remove[ind]][1] = data_dic[ind][1]
-                    del data_dic[ind]
 
             for data in data_dic:
-                changes.append([
-                    datetime.now().strftime("%d-%m-%Y %H:%M"),
-                    sheetname,
-                    "-",
-                    data + 2,
-                    data_dic[data][1],
-                    data_dic[data][0]
-                ])
+                new_value = data_dic[data][0]
+                old_value = data_dic[data][1]
+                if old_value and new_value and len(old_value) == len(new_value):
+                    for old, new in zip(old_value, new_value):
+                        if old != new:
+                            changes.append([
+                                datetime.now().strftime("%d-%m-%Y %H:%M"),
+                                sheetname,
+                                source_sht.columns.values.tolist()[new_value.index(new)],
+                                data + 2,
+                                old,
+                                new
+                            ])
+                else:
+                    changes.append([
+                        datetime.now().strftime("%d-%m-%Y %H:%M"),
+                        sheetname,
+                        "-",
+                        data + 2,
+                        old_value,
+                        new_value
+                    ])
         return changes
 
     def update_change_logs(self, logs, clone):
